@@ -1,4 +1,4 @@
-/*	$Id: Class1.h,v 1.4 2001/08/12 23:40:31 darren Exp $ */
+/*	$Id: Class1.h,v 1.5 2003/02/08 22:49:46 darren Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -165,7 +165,7 @@ public:
     u_int	modemXINFO() const;
     bool	setupReceive();
     bool	recvBegin(fxStr& emsg);
-    bool	recvPage(TIFF*, int& ppm, fxStr& emsg);
+    bool	recvPage(TIFF*, u_int& ppm, fxStr& emsg);
     bool	recvEnd(fxStr& emsg);
     void	recvAbort();
 
