@@ -1,4 +1,4 @@
-/*	$Id: Class2.h,v 1.6 2002/06/09 01:42:03 darren Exp $ */
+/*	$Id: Class2.h,v 1.7 2003/02/08 22:49:47 darren Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -145,7 +145,7 @@ public:
 // receive support
     bool	setupReceive();
     bool	recvBegin(fxStr& emsg);
-    bool	recvPage(TIFF*, int& ppm, fxStr& emsg);
+    bool	recvPage(TIFF*, u_int& ppm, fxStr& emsg);
     bool	recvEnd(fxStr& emsg);
     void	recvAbort();
 
