@@ -1,4 +1,4 @@
-/*	$Id: ClassModem.h,v 1.5 2002/02/02 20:03:09 darren Exp $ */
+/*	$Id: ClassModem.h,v 1.7 2003/04/02 04:27:33 darren Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -38,14 +38,14 @@ class Class2Params;
 
 // NB: these would be enums in the ClassModem class
 //     if there were a portable way to refer to them!
-typedef unsigned int CallStatus;	// return status from dialing op
-typedef	unsigned int CallType;		// type detected for incoming call
-typedef	unsigned int AnswerType;	// type of call to answer for
-typedef unsigned int SpeakerVolume;
-typedef	unsigned int ATResponse;	// response code from AT command
-typedef	unsigned int BaudRate;		// serial line communication rate
-typedef	unsigned int FlowControl;	// serial line flow control scheme
-typedef	unsigned int SetAction;		// how to act when setting line
+typedef u_int CallStatus;	// return status from dialing op
+typedef	u_int CallType;		// type detected for incoming call
+typedef	u_int AnswerType;	// type of call to answer for
+typedef u_int SpeakerVolume;
+typedef	u_int ATResponse;	// response code from AT command
+typedef	u_int BaudRate;		// serial line communication rate
+typedef	u_int FlowControl;	// serial line flow control scheme
+typedef	u_int SetAction;		// how to act when setting line
 typedef struct {
     const char*	msg;		// string to match
     u_short	len;		// string length
@@ -166,7 +166,8 @@ public:
 	AT_ERROR	= 9,	// "ERROR" response
 	AT_EMPTYLINE	= 10,	// empty line (0 characters received)
 	AT_TIMEOUT	= 11,	// timeout waiting for response
-	AT_OTHER	= 12	// unknown response (not one of above)
+	AT_XONXOFF	= 12,	// xon/xoff characters
+	AT_OTHER	= 13	// unknown response (not one of above)
     };
 private:
     ModemServer& server;	// server for getting to device
@@ -190,7 +191,7 @@ protected:
 
     static const char* serviceNames[9];	 // class 2 services
     static const char* callStatus[10];	 // printable call status
-    static const char* ATresponses[13];
+    static const char* ATresponses[14];
 
     ClassModem(ModemServer&, const ModemConfig&);
 
