@@ -1,4 +1,4 @@
-/*	$Id: FaxServer.h,v 1.3 2001/07/02 06:39:05 darren Exp $ */
+/*	$Id: FaxServer.h,v 1.5 2003/02/09 02:22:49 darren Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -76,7 +76,7 @@ private:
     TIFF*	setupForRecv(FaxRecvInfo&, FaxRecvInfoArray&, fxStr& emsg);
     bool	recvDocuments(TIFF*, FaxRecvInfo&, FaxRecvInfoArray&,
 		    fxStr& emsg);
-    bool	recvFaxPhaseD(TIFF* tif, FaxRecvInfo&, int& ppm, fxStr& emsg);
+    bool	recvFaxPhaseD(TIFF* tif, FaxRecvInfo&, u_int& ppm, fxStr& emsg);
     bool	pollFaxPhaseB(const fxStr& sep, const fxStr& pwd,
 		    FaxRecvInfoArray&, fxStr& emsg);
 protected:
@@ -117,6 +117,7 @@ public:
     const fxStr& getLocalIdentifier() const;
 
     bool modemSupports2D() const;
+    bool modemSupportsMMR() const;
     bool modemSupportsEOLPadding() const;
     bool modemSupportsVRes(float res) const;
     bool modemSupportsPageWidth(u_int w) const;
