@@ -1,4 +1,4 @@
-/*	$Id: ModemConfig.h,v 1.16 2002/09/13 16:55:18 darren Exp $ */
+/*	$Id: ModemConfig.h,v 1.18 2003/02/09 02:03:13 darren Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -64,6 +64,7 @@ public:
     fxStr	answerDataCmd;		// cmd for answering data call
     fxStr	answerFaxCmd;		// cmd for answering fax call
     fxStr	answerVoiceCmd;		// cmd for answering voice call
+    fxStr	ringResponse;		// cmd to respond after AT_RING
     fxStr	hardFlowCmd;		// cmd for hardware flow control
     fxStr	softFlowCmd;		// cmd for software flow control
     fxStr	noFlowCmd;		// cmd for disabling flow control
@@ -78,6 +79,7 @@ public:
     fxStr	onHookCmd;		// cmd for placing phone ``on hook''
     fxStr	softResetCmd;		// cmd for doing soft reset
     u_int	softResetCmdDelay;	// time in ms to pause after soft reset
+    u_int	ringTimeout;		// timeout in ms after RING to reset
     fxStr	waitTimeCmd;		// cmd for setting carrier wait time
     fxStr	pauseTimeCmd;		// cmd for setting "," pause time
     fxStr	mfrQueryCmd;		// cmd for getting modem manufacturer
@@ -98,6 +100,8 @@ public:
 					// caller id
     fxStr	cidName;		// pattern for name info
     fxStr	cidNumber;		// pattern for number info
+    u_int	cidNameAnswerLength;	// answer when CID received
+    u_int	cidNumberAnswerLength;	// answer when CID received
 
 					// protocol timers
     u_int	t1Timer;		// T.30 T1 timer (ms)
