@@ -1,4 +1,4 @@
-/*	$Id: pageSendApp.h,v 1.2 1999/06/13 07:41:07 robert Exp $ */
+/*	$Id: pageSendApp.h,v 1.4 2002/10/18 19:08:30 darren Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -71,9 +71,9 @@ private:
 
     static pageSendApp* _instance;
 
-    static const stringtag strings[];
-    static const stringtag atcmds[];
-    static const numbertag numbers[];
+    static stringtag strings[];
+    static stringtag atcmds[];
+    static numbertag numbers[];
 
 // configuration support
     void	setupConfig();
@@ -99,6 +99,7 @@ private:
     void	sendUcpPage(FaxRequest&, FaxMachineInfo&, const fxStr&, fxStr&);    bool	sendUcpMsg(FaxRequest&, faxRequest&, const fxStr&, fxStr&,
 		    FaxMachineInfo&);
 // modem handling
+    bool	canLockModem();
     bool	lockModem();
     void	unlockModem();
     bool	setupModem();
