@@ -1,4 +1,4 @@
-/*	$Id: SendFaxJob.h,v 1.5 2002/06/15 18:00:12 darren Exp $ */
+/*	$Id: SendFaxJob.h,v 1.6 2003/02/08 22:49:58 darren Exp $ */
 /*
  * Copyright (c) 1993-1996 Sam Leffler
  * Copyright (c) 1993-1996 Silicon Graphics, Inc.
@@ -31,8 +31,8 @@
 
 class SendFaxClient;
 
-typedef unsigned int FaxNotify;
-typedef	unsigned int FaxPageChop;
+typedef u_int FaxNotify;
+typedef	u_int FaxPageChop;
 
 class SendFaxJob : public fxObj {
 public:
