@@ -1,4 +1,4 @@
-/*	$Id: TypeRules.h,v 1.3 2002/05/03 18:17:42 darren Exp $ */
+/*	$Id: TypeRules.h,v 1.5 2003/04/15 21:44:03 tim Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -108,7 +108,7 @@ private:
     u_int match2(u_int base, const void* data, u_int size, bool verb) const;
 };
 
-typedef unsigned int TypeResult;		// conversion result
+typedef u_int TypeResult;		// conversion result
 
 /*
  * Type rules specify how to convert a file that is
@@ -162,7 +162,7 @@ public:
     TypeRule(const TypeRule& other);
     virtual ~TypeRule();
 
-    bool	match(const void*, u_int size, bool verbose = false) const;
+    bool	match(const void*, size_t size, bool verbose = false) const;
     bool	isContinuation() const;
 
     TypeResult	getResult() const;
