@@ -1,4 +1,4 @@
-/*	$Id: faxmsg.c,v 1.5 2002/10/01 14:13:43 darren Exp $ */
+/*	$Id: faxmsg.c,v 1.6 2003/02/08 22:22:18 darren Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -110,7 +110,7 @@ main(int argc, char** argv)
 	    spooldir = optarg;
 	    break;
 	case '?':
-	    fatal("Bad option `%c'; usage: %s %s", c, argv[0], usage);
+	    fatal("usage: %s %s", argv[0], usage);
 	    /*NOTREACHED*/
 	}
     if (optind == argc-1) {
